#include "KinectControl.h"
#include <iostream>
#include <unistd.h>
KinectControl xKinectControl;

const char * moveUp()
{
				int iA;
				int iB;
				KinectControl::MOTOR_STATUS eStatus;
				XnVector3D vVec;
				xKinectControl.GetInformation( iA, eStatus, vVec );
				iB=iA+6;
				if (iB < 32){
					xKinectControl.Move( iB );
					sleep(2);
					return("Command sent to Kinect.\n");
				}
				else
				{
					sleep(2);
					return("Reached upward maximum!\n");
				}
}

const char * moveDown()
{
				int iA;
				int iB;
				KinectControl::MOTOR_STATUS eStatus;
				XnVector3D vVec;
				xKinectControl.GetInformation( iA, eStatus, vVec );
				iB=iA-6;
				if (iB > -32){
					xKinectControl.Move( iB );
					sleep(2);
					return("Command sent to Kinect.\n");
				}
				else
				{
					sleep(2);
					return("Reached downward maximum!\n");
				}
}

const char* moveReset()
{
				xKinectControl.Move( 0 );
				sleep(2);
				return("Command sent to Kinect.\n");
}

int currStatus()
{
				int iA;
				KinectControl::MOTOR_STATUS eStatus;
				XnVector3D vVec;
				xKinectControl.GetInformation( iA, eStatus, vVec );
				return(iA);
}

const char* moveTo(int iTo)
{
if (iTo < -31 || iTo > 31)
					{
					return("Degree specified is outside the allowed parameters of the Kinect motor! Use --help for help.\n");
					}
				else
				{
					xKinectControl.Move( iTo );
					sleep(2);
					return("Command sent to Kinect.\n");
				}
}

int main(int argc, char *argv[])
{
	const char* helpText = "Controls the Kinect motor using the OpenNI driver.\n\nUsage: kinectmotorcontrol [degree, reset, up, down, status]\n\n  Degree\tInteger between -31 and 31 to tilt the Kinect to.\n  Reset\t\tTilts the Kinect to the degree of zero.\n  Up\t\tTilts the Kinect up by six degrees.\n  Down\t\tTilts the Kinect down by six degrees.\n  Status\tRetrieves the current degree of the Kinect.\n\n\nNOTE: If the value for degree does not change by at least six from the previous value, the Kinect may ignore the new value and the motor position will not change. Degree values returned are approximate and may be incorrect.\n\n\nThis software is distributed \"AS IS\", without warranty or implied warranty. By using this software you agree that the disributor and it's creator is not liable for any damages or loss of data that may occur.\n\n\n     ** Created by Anthony Smart | Copyright 2012 | All rights reserved **\n\n";
	uid_t uid=getuid(), euid=geteuid();
	if (uid<=0 || uid!=euid) {
		if ( argc != 2 )
		{
			printf("%s", helpText);
		}
		else if (strcmp (argv[1],"--help") == 0 || strcmp (argv[1],"/?") == 0)
		{
			printf("%s", helpText);
		}
		else if( xKinectControl.Create() == XN_STATUS_OK )
		{
			xKinectControl.SetLED( KinectControl::LED_BLINK_GREEN );
			if (strcmp (argv[1],"reset") == 0)
			{
				printf(moveReset());
			}
			else if (strcmp (argv[1],"up") == 0)
			{
				printf(moveUp());
			}
			else if (strcmp (argv[1],"down") == 0)
			{
				printf(moveDown());
			}
			else if (strcmp (argv[1],"status") == 0)
			{
				int iStatus = currStatus();
				printf("Degree is approximately %d .\n", iStatus);
			}
			else
			{
				printf(moveTo(atoi(argv[1])));
			}	
		}
		else
		{
		      printf("Kinect not found! Use --help for help.\n");
		}
		xKinectControl.Release();
	}
	else
	{
	    printf("Please run this program with root privileges!\n");
	}
}
